import {select, csv, scaleLinear, max, scaleBand, axisLeft, axisBottom} from 'd3';

const svg = select('svg');
const circle = svg.append('circle');

const width = +(svg.attr('width'));
const height = +(svg.attr('height'));

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top:20, right:20, bottom: 20, left: 120};
  
  const xScale = scaleLinear()
  		.domain([0, max(data, xValue)])
  		.range([0, width-150]);
  
  const yScale = scaleBand()
  		.domain(data.map(yValue))
  		.range([0, height/2])
  		.padding(0.1);
  
  const yAxis = axisLeft(yScale);
  
  const g = svg.append('g')
  		.attr('transform', 'translate('+margin.left+', '+margin.top+')');
  
  // yAxis(g.append('g'));
  g.append('g').call(yAxis);
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', 'translate(0,'+height/2+')');
  
	g.selectAll('rect').data(data)
	.enter().append('rect')
	.attr('y', d => yScale(yValue(d)))
	.attr('width', d => xScale(xValue(d)))
	.attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => {
	data.forEach(d => {
  	d.population = +d.population * 1000;
  });
  render(data);
});